@@ -97,7 +97,7 @@ static size_t xmlformat(char *dp, size_t max, const char *fmt, ...)
 {
     va_list args;
 
-    if(max < 0)
+    if(max < 1)
         return 0;
 
     va_start(args, fmt);
@@ -466,7 +466,7 @@ static void cgilock(void)
     char buf[65];
 
 retry:
-    fd = open(DEFAULT_VARPATH "/run/sipwitch/cgilock", O_CREAT|O_WRONLY|O_TRUNC|O_EXCL, 0755);
+    fd = open(DEFAULT_VARPATH "/run/sipwitch/cgilock", O_CREAT|O_WRONLY|O_TRUNC|O_EXCL, fsys::OWNER_PUBLIC);
     if(fd < 0) {
         opid = pidfile();
         if(!opid || opid == 1) {
@@ -812,7 +812,7 @@ static void response(char *buffer, unsigned max, const char *fmt, ...)
                 break;
             case 't':
                 tv = va_arg(args, time_t);
-                dt = DateTime::glt(&tv);
+                dt = DateTime::local(&tv);
                 if(dt->tm_year < 1800)
                     dt->tm_year += 1900;
                 count += xmlformat(buffer + count, max - count,
@@ -1025,7 +1025,7 @@ static void call_instance(void)
     mapped_view<MappedCall> cr(CALL_MAP);
     unsigned index = 0;
     char id[32];
-    MappedCall copy;
+    MappedCall map;
     char buffer[1024];
     rpcint_t diff = 0;
     time_t now;
@@ -1038,37 +1038,32 @@ static void call_instance(void)
         fault(5, "Invalid Command Argument");
 
 
-    unsigned count = cr.getCount();
+    unsigned count = cr.count();
     if(!count)
         fault(2, "Server Offline");
 
     time(&now);
     while(index < count) {
-        const MappedCall *map = const_cast<const MappedCall *>(cr(index++));
-
-        do {
-            memcpy((void *)&copy, map, sizeof(copy));
-        } while(memcmp(&copy, map, sizeof(copy)));
-        map = &copy;
-
-        if(!map->created)
+        cr.copy(index++, map);
+        if(!map.created)
             continue;
 
-        snprintf(id, sizeof(id), "%08x:%d", map->sequence, map->cid);
-        if(!String::equal(id, cid))
+        snprintf(id, sizeof(id), "%08x:%d", map.sequence, map.cid);
+        if(!eq(id, cid))
             continue;
 
-        if(map->active) {
+        if(map.active) {
             time(&now);
-            diff = (rpcint_t)(now - map->active);
+            diff = (rpcint_t)(now - map.active);
         }
 
         response(buffer, sizeof(buffer), "^(tsssssi)",
-            map->created, map->state + 1, map->authorized,
-            map->source, map->target, map->display, diff);
+            map.created, map.state + 1, map.authorized,
+            map.source, map.target, map.display, diff);
         reply(buffer);
     }
     fault(6, "Unknown Call");
+    reset_unsafe<MappedCall>(map);
 }
 
 static void call_range(void)
@@ -1077,12 +1072,12 @@ static void call_range(void)
     unsigned size;
     unsigned index = 0;
     char id[32];
-    MappedCall copy;
+    MappedCall map;
 
     if(params.argc != 0)
         fault(3, "Invalid Parameters");
 
-    unsigned count = cr.getCount();
+    unsigned count = cr.count();
     if(!count)
         fault(2, "Server Offline");
 
@@ -1091,28 +1086,24 @@ static void call_range(void)
     response(buffer, size, "^[");
 
     while(index < count) {
-        const MappedCall *map = const_cast<const MappedCall *>(cr(index++));
+        cr.copy(index++, map);
 
-        do {
-            memcpy(&copy, map, sizeof(copy));
-        } while(memcmp(&copy, map, sizeof(copy)));
-        map = &copy;
-
-        if(!map->created)
+        if(!map.created)
             continue;
 
-        snprintf(id, sizeof(id), "%08x:%d", map->sequence, map->cid);
+        snprintf(id, sizeof(id), "%08x:%d", map.sequence, map.cid);
         response(buffer, size, "!s", buffer);
     }
     response(buffer, size, "]");
     reply(buffer);
+    reset_unsafe<MappedCall>(map);
 }
 
 static void stat_periodic(void)
 {
     mapped_view<stats> sta(STAT_MAP);
     unsigned index = 0;
-    stats copy;
+    stats map;
     char buffer[1024];
 
     if(params.argc != 1)
@@ -1122,35 +1113,30 @@ static void stat_periodic(void)
     if(!cid || !*cid)
         fault(5, "Invalid Command Argument");
 
-    unsigned count = sta.getCount();
+    unsigned count = sta.count();
     if(!count)
         fault(2, "Server Offline");
 
     while(index < count) {
-        const stats *map = const_cast<const stats *>(sta(index++));
-
-        do {
-            memcpy(&copy, map, sizeof(copy));
-        } while(memcmp(&copy, map, sizeof(copy)));
-        map = &copy;
-
-        if(!String::equal(map->id, cid))
+        sta.copy(index++, map);
+        if(!eq(map.id, cid))
             continue;
 
         response(buffer, sizeof(buffer), "^(itiiiiii)",
-            (rpcint_t)map->limit, map->lastcall,
-            (rpcint_t)map->data[0].pperiod, (rpcint_t)map->data[0].pmin, (rpcint_t)map->data[0].pmax,
-            (rpcint_t)map->data[1].pperiod, (rpcint_t)map->data[1].pmin, (rpcint_t)map->data[1].pmax);
+            (rpcint_t)map.limit, map.lastcall,
+            (rpcint_t)map.data[0].pperiod, (rpcint_t)map.data[0].pmin, (rpcint_t)map.data[0].pmax,
+            (rpcint_t)map.data[1].pperiod, (rpcint_t)map.data[1].pmin, (rpcint_t)map.data[1].pmax);
         reply(buffer);
     }
     fault(7, "Unknown Stat");
+    reset_unsafe<stats>(map);
 }
 
 static void stat_instance(void)
 {
     mapped_view<stats> sta(STAT_MAP);
     unsigned index = 0;
-    stats copy;
+    stats map;
     char buffer[1024];
 
     if(params.argc != 1)
@@ -1160,28 +1146,23 @@ static void stat_instance(void)
     if(!cid || !*cid)
         fault(5, "Invalid Command Argument");
 
-    unsigned count = sta.getCount();
+    unsigned count = sta.count();
     if(!count)
         fault(2, "Server Offline");
 
     while(index < count) {
-        const stats *map = const_cast<const stats *>(sta(index++));
-
-        do {
-            memcpy(&copy, map, sizeof(copy));
-        } while(memcmp(&copy, map, sizeof(copy)));
-        map = &copy;
-
-        if(!String::equal(map->id, cid))
+        sta.copy(index++, map);
+        if(!eq(map.id, cid))
             continue;
 
         response(buffer, sizeof(buffer), "^(itiiiiii)",
-            (rpcint_t)map->limit, map->lastcall,
-            (rpcint_t)map->data[0].total, (rpcint_t)map->data[0].current, (rpcint_t)map->data[0].peak,
-            (rpcint_t)map->data[1].total, (rpcint_t)map->data[1].current, (rpcint_t)map->data[1].peak);
+            (rpcint_t)map.limit, map.lastcall,
+            (rpcint_t)map.data[0].total, (rpcint_t)map.data[0].current, (rpcint_t)map.data[0].peak,
+            (rpcint_t)map.data[1].total, (rpcint_t)map.data[1].current, (rpcint_t)map.data[1].peak);
         reply(buffer);
     }
     fault(7, "Unknown Stat");
+    reset_unsafe<stats>(map);
 }
 
 static void stat_range(void)
@@ -1189,12 +1170,12 @@ static void stat_range(void)
     mapped_view<stats> sta(STAT_MAP);
     unsigned size;
     unsigned index = 0;
-    stats copy;
+    stats map;
 
     if(params.argc != 0)
         fault(3, "Invalid Parameters");
 
-    unsigned count = sta.getCount();
+    unsigned count = sta.count();
     if(!count)
         fault(2, "Server Offline");
 
@@ -1203,20 +1184,15 @@ static void stat_range(void)
     response(buffer, size, "^[");
 
     while(index < count) {
-        const stats *map = const_cast<const stats *>(sta(index++));
-
-        do {
-            memcpy(&copy, map, sizeof(copy));
-        } while(memcmp(&copy, map, sizeof(copy)));
-        map = &copy;
-
-        if(!map->id[0])
+        sta.copy(index++, map);
+        if(!map.id[0])
             continue;
 
-        response(buffer, size, "!s", map->id);
+        response(buffer, size, "!s", map.id);
     }
     response(buffer, size, "]");
     reply(buffer);
+    reset_unsafe<stats>(map);
 }
 
 static void user_instance(void)
@@ -1224,7 +1200,7 @@ static void user_instance(void)
     mapped_view<MappedRegistry> reg(REGISTRY_MAP);
     unsigned index = 0;
     char ext[48];
-    MappedRegistry copy;
+    MappedRegistry map;
     char buffer[2048];
     time_t now;
     const char *status = "idle";
@@ -1236,37 +1212,32 @@ static void user_instance(void)
     if(!id || !*id)
         fault(5, "Invalid Command Argument");
 
-    unsigned count = reg.getCount();
+    unsigned count = reg.count();
     if(!count)
         fault(2, "Server Offline");
 
     time(&now);
     while(index < count) {
-        const MappedRegistry *map = const_cast<const MappedRegistry *>(reg(index++));
+        reg.copy(index++, map);
 
-        do {
-            memcpy(&copy, map, sizeof(copy));
-        } while(memcmp(&copy, map, sizeof(copy)));
-        map = &copy;
-
-        if(map->type != MappedRegistry::USER && map->type != MappedRegistry::SERVICE)
+        if(map.type != MappedRegistry::USER && map.type != MappedRegistry::SERVICE)
             continue;
 
-        if(map->expires < now)
+        if(map.expires < now)
             continue;
 
-        if(!String::equal(map->userid, id))
+        if(!eq(map.userid, id))
             continue;
 
-        if(map->ext)
-            snprintf(ext, sizeof(ext), "%u", map->ext);
+        if(map.ext)
+            snprintf(ext, sizeof(ext), "%u", map.ext);
         else
-            String::set(ext, sizeof(ext), map->userid);
+            String::set(ext, sizeof(ext), map.userid);
 
-        if(map->inuse)
+        if(map.inuse)
             status = "busy";
         else
-            switch(map->status) {
+            switch(map.status) {
             case MappedRegistry::AWAY:
                 status = "away";
                 break;
@@ -1281,11 +1252,12 @@ static void user_instance(void)
             }
 
         response(buffer, sizeof(buffer), "^(ssssii)",
-            ext, map->display, map->profile.id, status,
-            (rpcint_t)map->inuse, (rpcint_t)map->profile.level);
+            ext, map.display, map.profile.id, status,
+            (rpcint_t)map.inuse, (rpcint_t)map.profile.level);
         reply(buffer);
     }
     fault(8, "Unknown User");
+    reset_unsafe<MappedRegistry>(map);
 }
 
 static void user_range(void)
@@ -1293,12 +1265,12 @@ static void user_range(void)
     mapped_view<MappedRegistry> reg(REGISTRY_MAP);
     unsigned size;
     unsigned index = 0;
-    MappedRegistry copy;
+    MappedRegistry map;
 
     if(params.argc != 0)
         fault(3, "Invalid Parameters");
 
-    unsigned count = reg.getCount();
+    unsigned count = reg.count();
     if(!count)
         fault(2, "Server Offline");
 
@@ -1309,23 +1281,19 @@ static void user_range(void)
     time(&now);
 
     while(index < count) {
-        const MappedRegistry *map = const_cast<const MappedRegistry *>(reg(index++));
+        reg.copy(index++, map);
 
-        do {
-            memcpy(&copy, map, sizeof(copy));
-        } while(memcmp(&copy, map, sizeof(copy)));
-        map = &copy;
-
-        if(map->type != MappedRegistry::USER && map->type != MappedRegistry::SERVICE)
+        if(map.type != MappedRegistry::USER && map.type != MappedRegistry::SERVICE)
             continue;
 
-        if(map->expires < now)
+        if(map.expires < now)
             continue;
 
-        response(buffer, size, "!s", map->userid);
+        response(buffer, size, "!s", map.userid);
     }
     response(buffer, size, "]");
     reply(buffer);
+    reset_unsafe<MappedRegistry>(map);
 }
 
 static void server_realm(void)
@@ -1337,14 +1305,14 @@ static void server_realm(void)
     if(params.argc != 0)
         fault(3, "Invalid Parameters");
 
-    fsys::open(fd, DEFAULT_CFGPATH "/siprealm", fsys::ACCESS_RDONLY);
+    fd.open(DEFAULT_CFGPATH "/siprealm", fsys::RDONLY);
     if(!is(fd))
-        fsys::open(fd, DEFAULT_VARPATH "/lib/sipwitch/uuid", fsys::ACCESS_RDONLY);
+        fd.open(DEFAULT_VARPATH "/lib/sipwitch/uuid", fsys::RDONLY);
 
     if(is(fd)) {
         memset(realm, 0, sizeof(realm));
-        fsys::read(fd, realm, sizeof(realm) - 1);
-        fsys::close(fd);
+        fd.read(realm, sizeof(realm) - 1);
+        fd.close();
 
         char *cp = strchr(realm, '\n');
         if(cp)
@@ -1371,7 +1339,7 @@ static void server_status(void)
     if(params.argc != 0)
         fault(3, "Invalid Parameters");
 
-    unsigned count = cr.getCount();
+    unsigned count = cr.count();
     if(!count)
         fault(2, "Server Offline");
 
@@ -1585,7 +1553,7 @@ static void callfile(FILE *fp, const char *id)
     fstat(fileno(fp), &ino);
 #endif
 
-    dt = DateTime::glt(&ino.st_ctime);
+    dt = DateTime::local(&ino.st_ctime);
 
     if(dt->tm_year >= 2000)
         dt->tm_year -= 2000;
@@ -1683,9 +1651,8 @@ static void info(void)
 static void dumpcalls(const char *id)
 {
     mapped_view<MappedCall> calls(CALL_MAP);
-    unsigned count = calls.getCount();
+    unsigned count = calls.count();
     unsigned index = 0;
-    volatile const MappedCall *member;
     MappedCall buffer;
     char idbuf[32];
     time_t now;
@@ -1703,11 +1670,8 @@ static void dumpcalls(const char *id)
     time(&now);
 
     while(index < count) {
-        member = (const volatile MappedCall *)(calls(index++));
-        do {
-            memcpy(&buffer, (const void *)member, sizeof(buffer));
-        } while(memcmp(&buffer, (const void *)member, sizeof(buffer)));
-        if(!member->created)
+        calls.copy(index++, buffer);
+        if(!buffer.created)
             continue;
 
         snprintf(idbuf, sizeof(idbuf), "%08x:%u", buffer.sequence, buffer.cid);
@@ -1730,9 +1694,8 @@ static void dumpcalls(const char *id)
 static void dumpstats(const char *id)
 {
     mapped_view<stats> sta(STAT_MAP);
-    unsigned count = sta.getCount();
+    unsigned count = sta.count();
     unsigned index = 0;
-    volatile const stats *member;
     stats buffer;
     time_t now;
 
@@ -1749,13 +1712,10 @@ static void dumpstats(const char *id)
     time(&now);
 
     while(index < count) {
-        member = (const volatile stats *)(sta(index++));
-        do {
-            memcpy(&buffer, (const void *)member, sizeof(buffer));
-        } while(memcmp(&buffer, (const void *)member, sizeof(buffer)));
-        if(!member->id[0])
+        sta.copy(index++, buffer);
+        if(!buffer.id[0])
             continue;
-        if(id && !String::equal(id, buffer.id))
+        if(id && !eq(id, buffer.id))
             continue;
         printf(" <stat id=\"%s\">\n", buffer.id);
         printf("  <incoming>\n");
@@ -1780,9 +1740,8 @@ static void dumpstats(const char *id)
 static void registry(const char *id)
 {
     mapped_view<MappedRegistry> reg(REGISTRY_MAP);
-    unsigned count = reg.getCount();
+    unsigned count = reg.count();
     unsigned index = 0;
-    volatile const MappedRegistry *member;
     MappedRegistry buffer;
     time_t now;
     struct tm *dt;
@@ -1802,10 +1761,7 @@ static void registry(const char *id)
     printf("<mappedRegistry>\n");
     time(&now);
     while(index < count) {
-        member = (const volatile MappedRegistry *)(reg(index++));
-        do {
-            memcpy(&buffer, (const void *)member, sizeof(buffer));
-        } while(memcmp(&buffer, (const void *)member, sizeof(buffer)));
+        reg.copy(index++, buffer);
         if(buffer.type == MappedRegistry::EXPIRED)
             continue;
         else if(buffer.type == MappedRegistry::TEMPORARY && !buffer.inuse)
@@ -1846,7 +1802,7 @@ use:
         printf("  <type>%s</type>\n", type);
         printf("  <class>%s</class>\n", buffer.profile.id);
 
-        dt = DateTime::glt(&buffer.created);
+        dt = DateTime::local(&buffer.created);
         if(dt->tm_year < 1000)
             dt->tm_year += 1900;
 
@@ -1855,8 +1811,8 @@ use:
             dt->tm_hour, dt->tm_min, dt->tm_sec);
 
         DateTime::release(dt);
-        Socket::getaddress((struct sockaddr *)&buffer.contact, buf, sizeof(buf));
-        port = Socket::getservice((struct sockaddr *)&buffer.contact);
+        Socket::query((struct sockaddr *)&buffer.contact, buf, sizeof(buf));
+        port = Socket::service((struct sockaddr *)&buffer.contact);
         printf("  <address>%s</address>\n", buf);
         printf("  <service>%u</service>\n", port);
         printf(" </registry>\n");
